nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Ahbclkctrl0

Struct Ahbclkctrl0 

#[repr(transparent)]
pub struct Ahbclkctrl0(pub u32);
AHB Clock control 0

Tuple Fields

0: u32

Implementations

Source

impl Ahbclkctrl0

pub const fn rom(&self) -> bool

Enables the clock for the ROM.

pub const fn set_rom(&mut self, val: bool)

Enables the clock for the ROM.

pub const fn sram_ctrl1(&self) -> bool

Enables the clock for the SRAM Controller 1.

pub const fn set_sram_ctrl1(&mut self, val: bool)

Enables the clock for the SRAM Controller 1.

pub const fn sram_ctrl2(&self) -> bool

Enables the clock for the SRAM Controller 2.

pub const fn set_sram_ctrl2(&mut self, val: bool)

Enables the clock for the SRAM Controller 2.

pub const fn sram_ctrl3(&self) -> bool

Enables the clock for the SRAM Controller 3.

pub const fn set_sram_ctrl3(&mut self, val: bool)

Enables the clock for the SRAM Controller 3.

pub const fn sram_ctrl4(&self) -> bool

Enables the clock for the SRAM Controller 4.

pub const fn set_sram_ctrl4(&mut self, val: bool)

Enables the clock for the SRAM Controller 4.

pub const fn flash(&self) -> bool

Enables the clock for the Flash controller.

pub const fn set_flash(&mut self, val: bool)

Enables the clock for the Flash controller.

pub const fn fmc(&self) -> bool

Enables the clock for the FMC controller.

pub const fn set_fmc(&mut self, val: bool)

Enables the clock for the FMC controller.

pub const fn mux(&self) -> bool

Enables the clock for the Input Mux.

pub const fn set_mux(&mut self, val: bool)

Enables the clock for the Input Mux.

pub const fn iocon(&self) -> bool

Enables the clock for the I/O controller.

pub const fn set_iocon(&mut self, val: bool)

Enables the clock for the I/O controller.

pub const fn gpio0(&self) -> bool

Enables the clock for the GPIO0.

pub const fn set_gpio0(&mut self, val: bool)

Enables the clock for the GPIO0.

pub const fn gpio1(&self) -> bool

Enables the clock for the GPIO1.

pub const fn set_gpio1(&mut self, val: bool)

Enables the clock for the GPIO1.

pub const fn gpio2(&self) -> bool

Enables the clock for the GPIO2.

pub const fn set_gpio2(&mut self, val: bool)

Enables the clock for the GPIO2.

pub const fn gpio3(&self) -> bool

Enables the clock for the GPIO3.

pub const fn set_gpio3(&mut self, val: bool)

Enables the clock for the GPIO3.

pub const fn pint(&self) -> bool

Enables the clock for the Pin interrupt (PINT).

pub const fn set_pint(&mut self, val: bool)

Enables the clock for the Pin interrupt (PINT).

pub const fn gint(&self) -> bool

Enables the clock for the Group interrupt (GINT).

pub const fn set_gint(&mut self, val: bool)

Enables the clock for the Group interrupt (GINT).

pub const fn dma0(&self) -> bool

Enables the clock for the DMA0.

pub const fn set_dma0(&mut self, val: bool)

Enables the clock for the DMA0.

pub const fn crcgen(&self) -> bool

Enables the clock for the CRCGEN.

pub const fn set_crcgen(&mut self, val: bool)

Enables the clock for the CRCGEN.

pub const fn wwdt(&self) -> bool

Enables the clock for the Watchdog Timer.

pub const fn set_wwdt(&mut self, val: bool)

Enables the clock for the Watchdog Timer.

pub const fn rtc(&self) -> bool

Enables the clock for the Real Time Clock (RTC).

pub const fn set_rtc(&mut self, val: bool)

Enables the clock for the Real Time Clock (RTC).

pub const fn mailbox(&self) -> bool

Enables the clock for the Inter CPU communication Mailbox.

pub const fn set_mailbox(&mut self, val: bool)

Enables the clock for the Inter CPU communication Mailbox.

pub const fn adc(&self) -> bool

Enables the clock for the ADC.

pub const fn set_adc(&mut self, val: bool)

Enables the clock for the ADC.