nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

ClockCtrl

Struct ClockCtrl 

#[repr(transparent)]
pub struct ClockCtrl(pub u32);
Various system clock controls : Flash clock (48 MHz) control, clocks to Frequency Measures

Tuple Fields

0: u32

Implementations

Source

impl ClockCtrl

pub const fn xtal32mhz_freqm_ena(&self) -> bool

Enable XTAL32MHz clock for Frequency Measure module.

pub const fn set_xtal32mhz_freqm_ena(&mut self, val: bool)

Enable XTAL32MHz clock for Frequency Measure module.

pub const fn fro1mhz_utick_ena(&self) -> bool

Enable FRO 1MHz clock for Frequency Measure module and for UTICK.

pub const fn set_fro1mhz_utick_ena(&mut self, val: bool)

Enable FRO 1MHz clock for Frequency Measure module and for UTICK.

pub const fn fro12mhz_freqm_ena(&self) -> bool

Enable FRO 12MHz clock for Frequency Measure module.

pub const fn set_fro12mhz_freqm_ena(&mut self, val: bool)

Enable FRO 12MHz clock for Frequency Measure module.

pub const fn fro_hf_freqm_ena(&self) -> bool

Enable FRO 96MHz clock for Frequency Measure module.

pub const fn set_fro_hf_freqm_ena(&mut self, val: bool)

Enable FRO 96MHz clock for Frequency Measure module.

pub const fn clkin_ena(&self) -> bool

Enable clock_in clock for clock module.

pub const fn set_clkin_ena(&mut self, val: bool)

Enable clock_in clock for clock module.

pub const fn fro1mhz_clk_ena(&self) -> bool

Enable FRO 1MHz clock for clock muxing in clock gen.

pub const fn set_fro1mhz_clk_ena(&mut self, val: bool)

Enable FRO 1MHz clock for clock muxing in clock gen.

pub const fn ana_fro12m_clk_ena(&self) -> bool

Enable FRO 12MHz clock for analog control of the FRO 192MHz.

pub const fn set_ana_fro12m_clk_ena(&mut self, val: bool)

Enable FRO 12MHz clock for analog control of the FRO 192MHz.

pub const fn xo_cal_clk_ena(&self) -> bool

Enable clock for cristal oscilator calibration.

pub const fn set_xo_cal_clk_ena(&mut self, val: bool)

Enable clock for cristal oscilator calibration.

pub const fn plu_deglitch_clk_ena(&self) -> bool

Enable clocks FRO_1MHz and FRO_12MHz for PLU deglitching.

pub const fn set_plu_deglitch_clk_ena(&mut self, val: bool)

Enable clocks FRO_1MHz and FRO_12MHz for PLU deglitching.