#[repr(transparent)]pub struct Cpu1stckcal(pub u32);Expand description
System tick calibration for CPU1
Tuple Fields
0: u32Implementations
Sourceimpl Cpu1stckcal
impl Cpu1stckcal
Sourcepub const fn tenms(&self) -> u32
pub const fn tenms(&self) -> u32
Reload value for 10ms (100Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.
Sourcepub const fn set_tenms(&mut self, val: u32)
pub const fn set_tenms(&mut self, val: u32)
Reload value for 10ms (100Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.
Sourcepub const fn skew(&self) -> bool
pub const fn skew(&self) -> bool
Indicates whether the TENMS value is exact: 0 = TENMS value is exact; 1 = TENMS value is inexact, or not given.
Sourcepub const fn set_skew(&mut self, val: bool)
pub const fn set_skew(&mut self, val: bool)
Indicates whether the TENMS value is exact: 0 = TENMS value is exact; 1 = TENMS value is inexact, or not given.