#[repr(transparent)]pub struct Pll0ctrl(pub u32);Expand description
PLL0 550m control
Tuple Fields
0: u32Implementations
Sourceimpl Pll0ctrl
impl Pll0ctrl
Sourcepub const fn bypasspll(&self) -> Pll0ctrlBypasspll
pub const fn bypasspll(&self) -> Pll0ctrlBypasspll
Bypass PLL input clock is sent directly to the PLL output (default).
Sourcepub const fn set_bypasspll(&mut self, val: Pll0ctrlBypasspll)
pub const fn set_bypasspll(&mut self, val: Pll0ctrlBypasspll)
Bypass PLL input clock is sent directly to the PLL output (default).
Sourcepub const fn bypasspostdiv2(&self) -> Pll0ctrlBypasspostdiv2
pub const fn bypasspostdiv2(&self) -> Pll0ctrlBypasspostdiv2
bypass of the divide-by-2 divider in the post-divider.
Sourcepub const fn set_bypasspostdiv2(&mut self, val: Pll0ctrlBypasspostdiv2)
pub const fn set_bypasspostdiv2(&mut self, val: Pll0ctrlBypasspostdiv2)
bypass of the divide-by-2 divider in the post-divider.
Sourcepub const fn limupoff(&self) -> bool
pub const fn limupoff(&self) -> bool
limup_off = 1 in spread spectrum and fractional PLL applications.
Sourcepub const fn set_limupoff(&mut self, val: bool)
pub const fn set_limupoff(&mut self, val: bool)
limup_off = 1 in spread spectrum and fractional PLL applications.
Sourcepub const fn bwdirect(&self) -> Pll0ctrlBwdirect
pub const fn bwdirect(&self) -> Pll0ctrlBwdirect
Control of the bandwidth of the PLL.
Sourcepub const fn set_bwdirect(&mut self, val: Pll0ctrlBwdirect)
pub const fn set_bwdirect(&mut self, val: Pll0ctrlBwdirect)
Control of the bandwidth of the PLL.
Sourcepub const fn bypassprediv(&self) -> Pll0ctrlBypassprediv
pub const fn bypassprediv(&self) -> Pll0ctrlBypassprediv
bypass of the pre-divider.
Sourcepub const fn set_bypassprediv(&mut self, val: Pll0ctrlBypassprediv)
pub const fn set_bypassprediv(&mut self, val: Pll0ctrlBypassprediv)
bypass of the pre-divider.
Sourcepub const fn bypasspostdiv(&self) -> Pll0ctrlBypasspostdiv
pub const fn bypasspostdiv(&self) -> Pll0ctrlBypasspostdiv
bypass of the post-divider.
Sourcepub const fn set_bypasspostdiv(&mut self, val: Pll0ctrlBypasspostdiv)
pub const fn set_bypasspostdiv(&mut self, val: Pll0ctrlBypasspostdiv)
bypass of the post-divider.
Sourcepub const fn frmclkstable(&self) -> bool
pub const fn frmclkstable(&self) -> bool
free running mode clockstable: Warning: Only make frm_clockstable =1 after the PLL output frequency is stable.
Sourcepub const fn set_frmclkstable(&mut self, val: bool)
pub const fn set_frmclkstable(&mut self, val: bool)
free running mode clockstable: Warning: Only make frm_clockstable =1 after the PLL output frequency is stable.
Sourcepub const fn set_skewen(&mut self, val: bool)
pub const fn set_skewen(&mut self, val: bool)
skew mode.