#[repr(transparent)]pub struct Pll0sscg1(pub u32);Expand description
PLL0 Spread Spectrum Wrapper control register 1
Tuple Fields
0: u32Implementations
Sourceimpl Pll0sscg1
impl Pll0sscg1
Sourcepub const fn set_md_mbs(&mut self, val: bool)
pub const fn set_md_mbs(&mut self, val: bool)
input word of the wrapper bit 32.
Sourcepub const fn set_md_req(&mut self, val: bool)
pub const fn set_md_req(&mut self, val: bool)
md change request.
Sourcepub const fn mf(&self) -> u8
pub const fn mf(&self) -> u8
programmable modulation frequency fm = Fref/Nss mf[2:0] = 000 => Nss=512 (fm ~ 3.
Sourcepub const fn set_mf(&mut self, val: u8)
pub const fn set_mf(&mut self, val: u8)
programmable modulation frequency fm = Fref/Nss mf[2:0] = 000 => Nss=512 (fm ~ 3.
Sourcepub const fn mr(&self) -> u8
pub const fn mr(&self) -> u8
programmable frequency modulation depth Dfmodpk-pk = Frefkss/Fcco = kss/(2md[32:25]dec) mr[2:0] = 000 => kss = 0 (no spread spectrum) mr[2:0] = 001 => kss ~ 1 mr[2:0] = 010 => kss ~ 1.
Sourcepub const fn set_mr(&mut self, val: u8)
pub const fn set_mr(&mut self, val: u8)
programmable frequency modulation depth Dfmodpk-pk = Frefkss/Fcco = kss/(2md[32:25]dec) mr[2:0] = 000 => kss = 0 (no spread spectrum) mr[2:0] = 001 => kss ~ 1 mr[2:0] = 010 => kss ~ 1.
Sourcepub const fn mc(&self) -> u8
pub const fn mc(&self) -> u8
modulation waveform control Compensation for low pass filtering of the PLL to get a triangular modulation at the output of the PLL, giving a flat frequency spectrum.
Sourcepub const fn set_mc(&mut self, val: u8)
pub const fn set_mc(&mut self, val: u8)
modulation waveform control Compensation for low pass filtering of the PLL to get a triangular modulation at the output of the PLL, giving a flat frequency spectrum.
Sourcepub const fn set_mdiv_ext(&mut self, val: u16)
pub const fn set_mdiv_ext(&mut self, val: u16)
to select an external mdiv value.
Sourcepub const fn dither(&self) -> bool
pub const fn dither(&self) -> bool
dithering between two modulation frequencies in a random way or in a pseudo random way (white noise), in order to decrease the probability that the modulated waveform will occur with the same phase on a particular point on the screen.
Sourcepub const fn set_dither(&mut self, val: bool)
pub const fn set_dither(&mut self, val: bool)
dithering between two modulation frequencies in a random way or in a pseudo random way (white noise), in order to decrease the probability that the modulated waveform will occur with the same phase on a particular point on the screen.
Sourcepub const fn sel_ext(&self) -> bool
pub const fn sel_ext(&self) -> bool
to select mdiv_ext and mreq_ext sel_ext = 0: mdiv ~ md[32:0], mreq = 1 sel_ext = 1 : mdiv = mdiv_ext, mreq = mreq_ext.
Sourcepub const fn set_sel_ext(&mut self, val: bool)
pub const fn set_sel_ext(&mut self, val: bool)
to select mdiv_ext and mreq_ext sel_ext = 0: mdiv ~ md[32:0], mreq = 1 sel_ext = 1 : mdiv = mdiv_ext, mreq = mreq_ext.